@@ -1,6 +1,8 @@
 tabmeans.svy <- function(x, y, svy, latex = FALSE, xlevels = NULL, yname = "Y variable", 
                          test = "Wald", decimals = 1, p.decimals = c(2, 3), p.cuts = 0.01, 
-                         p.lowerbound = 0.001, p.leading0 = TRUE, p.avoid1 = FALSE, n = FALSE) {
+                         p.lowerbound = 0.001, p.leading0 = TRUE, p.avoid1 = FALSE, n.column = FALSE,
+                         n.headings = TRUE, bold.colnames = TRUE, bold.varnames = FALSE, 
+                         variable.colname = "Variable") {
   
   # If any inputs are not correct class, return error
   if (!is.logical(latex)) {
@@ -33,8 +35,20 @@ tabmeans.svy <- function(x, y, svy, latex = FALSE, xlevels = NULL, yname = "Y va
   if (!is.logical(p.avoid1)) {
     stop("For p.avoid1 input, please enter TRUE or FALSE")
   }
-  if (!is.logical(n)) {
-    stop("For n input, please enter TRUE or FALSE")
+  if (!is.logical(n.column)) {
+    stop("For n.column input, please enter TRUE or FALSE")
+  }
+  if (!is.logical(n.headings)) {
+    stop("For n.headings input, please enter TRUE or FALSE")
+  }
+  if (!is.logical(bold.colnames)) {
+    stop("For bold.colnames input, please enter TRUE or FALSE")
+  }
+  if (!is.logical(bold.varnames)) {
+    stop("For bold.varnames input, please enter TRUE or FALSE")
+  }
+  if (!is.character(variable.colname)) {
+    stop("For variable.colname input, please enter a character string")
   }
   
   # Convert decimals to variable for sprintf
@@ -68,7 +82,7 @@ tabmeans.svy <- function(x, y, svy, latex = FALSE, xlevels = NULL, yname = "Y va
   }
   
   # Initialize table
-  tbl <- matrix("", nrow = 1, ncol = length(xlevels)+4)
+  tbl <- matrix("", nrow = 1, ncol = length(xlevels) + 4)
   
   # Get means and SE's overall and by levels of x, and get sample size in each x
   totmean <- svymean(y, design = svy2)
@@ -87,11 +101,15 @@ tabmeans.svy <- function(x, y, svy, latex = FALSE, xlevels = NULL, yname = "Y va
   pval <- anova(fit1, fit2, method = test)$p
   tbl[1, ncol(tbl)] <- formatp(p = pval, cuts = p.cuts, decimals = p.decimals, lowerbound = p.lowerbound, leading0 = p.leading0, avoid1 = p.avoid1)
   
-  # Add column names
-  colnames(tbl) <- c("Variable", "N", "Overall", xlevels, "P")
+  # Add column names, with sample sizes for each group if requested
+  if (n.headings == FALSE) {
+    colnames(tbl) <- c(variable.colname, "N", "Overall", xlevels, "P")
+  } else {
+    colnames(tbl) <- c(variable.colname, "N", paste(c("Overall", xlevels), " (n = ", c(sum(ns), ns), ")", sep = ""), "P")
+  }
   
   # Drop N column if requested
-  if (n == FALSE) {
+  if (n.column == FALSE) {
     tbl <- tbl[, -which(colnames(tbl) == "N"), drop = FALSE]
   }
   
@@ -101,6 +119,12 @@ tabmeans.svy <- function(x, y, svy, latex = FALSE, xlevels = NULL, yname = "Y va
     if (length(plocs) > 0) {
       tbl[plocs, "P"] <- paste("$<$", substring(tbl[plocs, "P"], 2), sep = "")
     }
+    if (bold.colnames == TRUE) {
+      colnames(tbl) <- paste("$\\textbf{", colnames(tbl), "}$", sep = "")
+    }
+    if (bold.varnames == TRUE) {
+      tbl[1, 1] <- paste("$\\textbf{", tbl[1, 1], "}$")
+    }
   }
   
   # Return table
